@@ -5,6 +5,7 @@ from django.utils.module_loading import import_string
 from faust import StreamT
 
 from .services import UserService
+from .settings import CONSUMER_APP_ENV
 
 app = import_string(settings.IDP_USER_APP['FAUST_APP_PATH'])
 
@@ -19,7 +20,7 @@ app = import_string(settings.IDP_USER_APP['FAUST_APP_PATH'])
         "app_identifier": {
             "tenant": {
                 "Servicer": {
-                    "app_config": {"vehicle_ids": [1, 2]},
+                    "app_entities_restrictions": {"vehicle": [1, 2]},
                     "permission_restrictions": {
                         "synchronizeDoD": False
                     }
@@ -37,17 +38,21 @@ class UserRecord(faust.Record):
     last_name: str = None
     username: str = None
     email: str = None
+    is_active: bool = None
+    is_staff: bool = None
+    is_superuser: bool = None
+    date_joined: str = None
     app_specific_configs: dict = None
 
 
-USER_UPDATES_TOPIC_NAME = f"{settings.APP_ENV}_user_updates"
+USER_UPDATES_TOPIC_NAME = f"{CONSUMER_APP_ENV}_user_updates"
 
 user_updates = app.topic(USER_UPDATES_TOPIC_NAME, value_type=UserRecord)
 
 
 @sync_to_async
 def update_user(user_record: UserRecord):
-    UserService.update_user(user_record.asdict())
+    UserService.process_user(user_record.asdict())
 
 
 @app.agent(user_updates)
